'use strict';

const chalk = require('chalk');

class HttpAgent {
    
    constructor(delegate){
        this.server = null;
        this.delegate = delegate;
    }

    start(port, cb){
        if( this.status() === 'RUNNING' ){
            return console.log(chalk.red('HTTP AGENT (WARN): The application is already running!'));
        }
        
        port = port || 3000;

        this.server = this.delegate.listen(port, cb || function(){
            console.log(chalk.blue('HTTP AGENT (INFO): The application is listening on port'), chalk.green(port));
        });

        return this.server;
    }

    stop(cb){
        if( this.server === null ) {
          return console.log(chalk.red('HTTP AGENT (WARN): There is no server being managed by this agent! Try `agent.start()` instead...'));
        }
        this.server.close(cb || function(){
            console.log(chalk.green('HTTP AGENT (INFO): The application was stopped, gracefully!'));
        });

        return this.server;
    }

    restart(cb){
        if( this.status() === 'STOPPED' || this.status() === 'OFFLINE' ){
            this.start();
        }else{
            this.stop(function(){
                this.start();
                (cb || function(){})();
            }.bind(this));
        }

        return this.server
    }

    status(){
        if( this.server === null ){
            return 'OFFLINE';
        }else if( this.server.address() === null ){
            return 'STOPPED';
        }else{
            return 'RUNNING';
        }
    }

    getServer() {
      return this.server;
    }
}

module.exports = HttpAgent;
